#
# spec file for package python-opentelemetry-proto
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-proto
# Please keep in sync with python-opentelemetry-exporter-otlp-*
Version:        1.33.1
Release:        1.1
Summary:        OpenTelemetry Python Proto
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry-proto/opentelemetry_proto-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module protobuf >= 5.0}
BuildRequires:  %{python_module pytest}
# /SECTION
BuildRequires:  fdupes
Requires:       python-protobuf >= 5.0
BuildArch:      noarch
%python_subpackages

%description
This library contains the generated code for OpenTelemetry protobuf data model.
The code in the current package was generated using the v0.17.0 release_ of
opentelemetry-proto.

%prep
%autosetup -p1 -n opentelemetry_proto-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%dir %{python_sitelib}/opentelemetry
%{python_sitelib}/opentelemetry/proto
%{python_sitelib}/opentelemetry_proto-%{version}.dist-info

%changelog
* Mon May 26 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 1.33.1
  * Remove log messages from BatchLogRecordProcessor.emit, this caused the
    program to crash at shutdown with a max recursion error
- Update to 1.33.0
  * Fix intermittent Connection aborted error when using otlp/http exporters
  * opentelemetry-sdk: use stable code attributes:
    code.function -> code.function.name, code.lineno -> code.line.number,
    code.filepath -> code.file.path
  * Fix serialization of extended attributes for logs signal
  * Handle OTEL_PROPAGATORS contains None
  * docs: updated and added to the metrics and log examples
  * Bump semantic conventions to 1.33.0
* Mon May  5 2025 Dirk Müller <dmueller@suse.com>
- update to 1.32.1:
  * Fix user agent in OTLP HTTP metrics exporter
  * Improve performance of baggage operations
  * sdk: remove duplicated constant definitions for
    `environment_variables`
  * api: Revert record `BaseException` change in
    `trace_api.use_span()`
  * Improve CI by cancelling stale runs and setting timeouts
  * Patch logging.basicConfig so OTel logs don't cause console
    logs to disappear
  * Bump semantic conventions to 1.32.0
  * Fix ExplicitBucketHistogramAggregation to handle multiple
    explicit bucket boundaries advisories
  * opentelemetry-sdk: Fix serialization of objects in log
    handler
- update to 1.31.1:
  * api: Revert record `BaseException` change in
    `trace_api.use_span()`
- update to 1.31.0:
  * Add type annotations to context's attach & detach
  * Fix OTLP encoders missing instrumentation scope schema url
    and attributes
  * prometheus-exporter: fix labels out of place for data points
    with different attribute sets
  * Type indent parameter in to_json
  * Tolerates exceptions when loading resource detectors via
    `OTEL_EXPERIMENTAL_RESOURCE_DETECTORS`
  * Disconnect gRPC client stub when shutting down
    `OTLPSpanExporter`
  * opentelemetry-sdk: fix OTLP exporting of Histograms with
    explicit buckets advisory
  * opentelemetry-exporter-otlp-proto-grpc: better dependency
    version range for Python 3.13
  * opentelemetry-exporter-opencensus: better dependency version
    range for Python 3.13
  * Updated `tracecontext-integration-test` gitref to
    `d782773b2cf2fa4afd6a80a93b289d8a74ca894d`
  * Make `trace_api.use_span()` record `BaseException` as well as
    `Exception`
  * Fix env var error message for TraceLimits/SpanLimits
  * pylint-ci updated python version to 3.13
* Tue Feb 25 2025 Dirk Müller <dmueller@suse.com>
- update to 1.30.0:
  * Always setup logs sdk,
    OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED only
    controls python `logging` module handler setup
  * Add `attributes` field in `metrics.get_meter` wrapper
    function
  * Add Python 3.13 support
  * sdk: don't log or print warnings when the SDK has been
    disabled
  * Fix span context manager typing by using ParamSpec from
    typing_extensions
  * Fix serialization of None values in logs body to match
    1.31.0+ data model
  * [BREAKING] semantic-conventions: Remove `opentelemetry.semcon
    v.attributes.network_attributes.NETWORK_INTERFACE_NAME`
    introduced by mistake in the wrong module.
  * Add support for explicit bucket boundaries advisory for
    Histograms
  * semantic-conventions: Bump to 1.30.0
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 1.29.0
  * Fix crash exporting a log record with None body
  * Fix metrics export with exemplar and no context and filtering observable instruments
  * Fix recursion error with sdk disabled and handler added to root logger
  * sdk: setup EventLogger when OTEL_PYTHON_LOGGING_AUTO_INSTRUMENTATION_ENABLED is set
  * api: fix logging of duplicate EventLogger setup warning
  * sdk: fix setting of process owner in ProcessResourceDetector
  * sdk: fix serialization of logs severity_number field to int
  * Remove `TestBase.assertEqualSpanInstrumentationInfo` method,
    use `assertEqualSpanInstrumentationScope` instead
  * sdk: instantiate lazily `ExemplarBucket`s in `ExemplarReservoir`s
  * semantic-conventions: Bump to 1.29.0
- from version 1.28.0
  * Removed superfluous py.typed markers and added them where they were missing
  * Include metric info in encoding exceptions
  * sdk: Add support for log formatting
  * sdk: Add Host resource detector
  * sdk: Implementation of exemplars
  * Implement events sdk
  * Update semantic conventions to version 1.28.0
  * Add support to protobuf 5+ and drop support to protobuf 3 and 4
  * Update environment variable descriptions to match signal
  * Record logger name as the instrumentation scope name
  * Fix memory leak in exporter and reader
  * Drop `OTEL_PYTHON_EXPERIMENTAL_DISABLE_PROMETHEUS_UNIT_NORMALIZATION` environment variable
  * Improve compatibility with other logging libraries that override
    `LogRecord.getMessage()` in order to customize message formatting
- Update BuildRequires and Requires from pyproject.toml
* Wed Sep  4 2024 Guang Yee <gyee@suse.com>
- update to 1.27.0:
  * Implementation of Events API
  * Make log sdk add exception.message to logRecord for exceptions whose argument is an exception not a string message
  * Fix use of link.attributes.dropped, which may not exist
  * Running mypy on SDK resources
  * Added py.typed file to top-level module
  * Drop Final annotation from Enum in semantic conventions
  * Update log export example to not use root logger
  * Update semantic conventions to version 1.27.0
  * Add support to type bytes for OTLP AnyValue
  * Export ExponentialHistogram and ExponentialHistogramDataPoint
  * Implement Client Key and Certificate File Support for All OTLP Exporters
  * Remove _start_time_unix_nano attribute from _ViewInstrumentMatch in favor of using time_ns() at the moment when the aggregation object is created
* Thu Jun  6 2024 Dirk Müller <dmueller@suse.com>
- update to 1.25.0:
  * Add OpenTelemetry trove classifiers to PyPI packages
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 1.24.0:
  * Make create_gauge non-abstract method
  * Make `tracer.start_as_current_span()` decorator work with
    async functions
  * Fix python 3.12 deprecation warning
  * bump mypy to 0.982
  * Add support for OTEL_SDK_DISABLED environment variable
  * Fix ValueError message for PeriodicExportingMetricsReader
  * Use `BaseException` instead of `Exception` in
    `record_exception`
  * Make span.record_exception more robust
  * Fix license field in pyproject.toml files
* Fri Mar 22 2024 Dirk Müller <dmueller@suse.com>
- update to 1.23.0:
  * drop python 3.7 support
  * update to opentelemetry 0.20.0 data model, which includes:
    + Handle HTTP 2XX responses as successful in OTLP exporters
* Mon Jan 15 2024 Dirk Müller <dmueller@suse.com>
- Initial package (1.22.0)
